/*
 * Copyright 2017-2018 NXP
 * All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NXP "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NXP OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef OC_IRQ_H
#define OC_IRQ_H

#include "oc_pal_mapping.h"
#include "interrupt_manager.h"


/*******************************************************************************
 * Prototypes
 ******************************************************************************/
void OC_IrqHandler(uint32_t instance, uint8_t channel);

/*******************************************************************************
 *  Default interrupt handlers signatures
 ******************************************************************************/

/* Define OC PAL over FTM */
#if (defined(OC_PAL_OVER_FTM))

#if (OC_PAL_INSTANCES_MAX > 0U)
#if (FEATURE_FTM_HAS_NUM_IRQS_CHANS == 1U)
void FTM0_Ch0_7_IrqHandler(void);
#else
void FTM0_Ch0_Ch1_IrqHandler(void);

void FTM0_Ch2_Ch3_IrqHandler(void);

void FTM0_Ch4_Ch5_IrqHandler(void);

void FTM0_Ch6_Ch7_IrqHandler(void);
#endif /* FEATURE_FTM_HAS_NUM_IRQS_CHANS == 1U */
#endif /* OC_PAL_INSTANCES_MAX > 0U */

#if (OC_PAL_INSTANCES_MAX > 1U)
#if (FEATURE_FTM_HAS_NUM_IRQS_CHANS == 1U)
void FTM1_Ch0_7_IrqHandler(void);
#else
void FTM1_Ch0_Ch1_IrqHandler(void);

void FTM1_Ch2_Ch3_IrqHandler(void);

void FTM1_Ch4_Ch5_IrqHandler(void);

void FTM1_Ch6_Ch7_IrqHandler(void);
#endif /* FEATURE_FTM_HAS_NUM_IRQS_CHANS == 1U */
#endif /* OC_PAL_INSTANCES_MAX > 1U */

#if (OC_PAL_INSTANCES_MAX > 2U)
void FTM2_Ch0_Ch1_IrqHandler(void);

void FTM2_Ch2_Ch3_IrqHandler(void);

void FTM2_Ch4_Ch5_IrqHandler(void);

void FTM2_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 2U */

#if (OC_PAL_INSTANCES_MAX > 3U)
void FTM3_Ch0_Ch1_IrqHandler(void);

void FTM3_Ch2_Ch3_IrqHandler(void);

void FTM3_Ch4_Ch5_IrqHandler(void);

void FTM3_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 3U */

#if (OC_PAL_INSTANCES_MAX > 4U)
void FTM4_Ch0_Ch1_IrqHandler(void);

void FTM4_Ch2_Ch3_IrqHandler(void);

void FTM4_Ch4_Ch5_IrqHandler(void);

void FTM4_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 4U */

#if (OC_PAL_INSTANCES_MAX > 5U)
void FTM5_Ch0_Ch1_IrqHandler(void);

void FTM5_Ch2_Ch3_IrqHandler(void);

void FTM5_Ch4_Ch5_IrqHandler(void);

void FTM5_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 5U */

#if (OC_PAL_INSTANCES_MAX > 6U)
void FTM6_Ch0_Ch1_IrqHandler(void);

void FTM6_Ch2_Ch3_IrqHandler(void);

void FTM6_Ch4_Ch5_IrqHandler(void);

void FTM6_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 6U */

#if (OC_PAL_INSTANCES_MAX > 7U)
void FTM7_Ch0_Ch1_IrqHandler(void);

void FTM7_Ch2_Ch3_IrqHandler(void);

void FTM7_Ch4_Ch5_IrqHandler(void);

void FTM7_Ch6_Ch7_IrqHandler(void);
#endif /* OC_PAL_INSTANCES_MAX > 7U */
/* Array storing references to OC PAL over FTM irq handlers */
extern const isr_t s_ocOverFtmIsr[OC_PAL_INSTANCES_MAX][FTM_CONTROLS_COUNT];

#endif /* OC_PAL_OVER_FTM */

#if (defined(OC_PAL_OVER_EMIOS))

#if (OC_PAL_INSTANCES_MAX > 0U)
void EMIOS0_00_01_IRQHandler(void);
void EMIOS0_02_03_IRQHandler(void);
void EMIOS0_04_05_IRQHandler(void);
void EMIOS0_06_07_IRQHandler(void);
void EMIOS0_08_09_IRQHandler(void);
void EMIOS0_10_11_IRQHandler(void);
void EMIOS0_12_13_IRQHandler(void);
void EMIOS0_14_15_IRQHandler(void);
void EMIOS0_16_17_IRQHandler(void);
void EMIOS0_18_19_IRQHandler(void);
void EMIOS0_20_21_IRQHandler(void);
void EMIOS0_22_23_IRQHandler(void);
void EMIOS0_24_25_IRQHandler(void);
void EMIOS0_26_27_IRQHandler(void);
void EMIOS0_28_29_IRQHandler(void);
void EMIOS0_30_31_IRQHandler(void);
#endif

#if (OC_PAL_INSTANCES_MAX > 1U)
void EMIOS1_00_01_IRQHandler(void);
void EMIOS1_02_03_IRQHandler(void);
void EMIOS1_04_05_IRQHandler(void);
void EMIOS1_06_07_IRQHandler(void);
void EMIOS1_08_09_IRQHandler(void);
void EMIOS1_10_11_IRQHandler(void);
void EMIOS1_12_13_IRQHandler(void);
void EMIOS1_14_15_IRQHandler(void);
void EMIOS1_16_17_IRQHandler(void);
void EMIOS1_18_19_IRQHandler(void);
void EMIOS1_20_21_IRQHandler(void);
void EMIOS1_22_23_IRQHandler(void);
void EMIOS1_24_25_IRQHandler(void);
void EMIOS1_26_27_IRQHandler(void);
void EMIOS1_28_29_IRQHandler(void);
void EMIOS1_30_31_IRQHandler(void);
#endif

#if (OC_PAL_INSTANCES_MAX > 2U)
void EMIOS2_00_01_IRQHandler(void);
void EMIOS2_02_03_IRQHandler(void);
void EMIOS2_04_05_IRQHandler(void);
void EMIOS2_06_07_IRQHandler(void);
void EMIOS2_08_09_IRQHandler(void);
void EMIOS2_10_11_IRQHandler(void);
void EMIOS2_12_13_IRQHandler(void);
void EMIOS2_14_15_IRQHandler(void);
void EMIOS2_16_17_IRQHandler(void);
void EMIOS2_18_19_IRQHandler(void);
void EMIOS2_20_21_IRQHandler(void);
void EMIOS2_22_23_IRQHandler(void);
void EMIOS2_24_25_IRQHandler(void);
void EMIOS2_26_27_IRQHandler(void);
void EMIOS2_28_29_IRQHandler(void);
void EMIOS2_30_31_IRQHandler(void);
#endif

#endif /* defined(OC_PAL_OVER_EMIOS) */

#if (defined(OC_PAL_OVER_ETIMER))

#if (OC_PAL_INSTANCES_MAX > 0U)
void ETIMER0_TC0IR_IRQHandler(void);
void ETIMER0_TC1IR_IRQHandler(void);
void ETIMER0_TC2IR_IRQHandler(void);
void ETIMER0_TC3IR_IRQHandler(void);
void ETIMER0_TC4IR_IRQHandler(void);
void ETIMER0_TC5IR_IRQHandler(void);
#endif

#if (OC_PAL_INSTANCES_MAX > 1U)
void ETIMER1_TC0IR_IRQHandler(void);
void ETIMER1_TC1IR_IRQHandler(void);
void ETIMER1_TC2IR_IRQHandler(void);
void ETIMER1_TC3IR_IRQHandler(void);
void ETIMER1_TC4IR_IRQHandler(void);
void ETIMER1_TC5IR_IRQHandler(void);
#endif

#if (OC_PAL_INSTANCES_MAX > 2U)
void ETIMER2_TC0IR_IRQHandler(void);
void ETIMER2_TC1IR_IRQHandler(void);
void ETIMER2_TC2IR_IRQHandler(void);
void ETIMER2_TC3IR_IRQHandler(void);
void ETIMER2_TC4IR_IRQHandler(void);
void ETIMER2_TC5IR_IRQHandler(void);
#endif

#endif /* defined(OC_PAL_OVER_ETIMER) */

#endif /* OC_IRQ_H */

/*******************************************************************************
 * EOF
 ******************************************************************************/
